@@ -1,6 +1,6 @@
 from django.contrib.admin.filters import (AllValuesFieldListFilter,
                                           RelatedFieldListFilter,
-                                          SimpleListFilter, )
+                                          SimpleListFilter, ChoicesFieldListFilter, )
 from django.db.models.query_utils import Q
 from django.utils.encoding import smart_str
 from django.utils.translation import ugettext as _
@@ -35,6 +35,14 @@ class RelatedFieldRadioFilter(RelatedFieldListFilter):
     template = 'adminfilters/fieldradio.html'
 
 
+class ChoicesFieldComboFilter(ChoicesFieldListFilter):
+    template = 'adminfilters/combobox.html'
+
+
+class ChoicesFieldRadioFilter(ChoicesFieldListFilter):
+    template = 'adminfilters/fieldradio.html'
+
+
 class RelatedFieldCheckBoxFilter(RelatedFieldListFilter):
     template = 'adminfilters/fieldcheckbox.html'
 
